==> wpackagist-plugin-complianz-gdpr-premium-4.1.5.1.zip: pro/config/warnings.php <==
<?php
defined('ABSPATH') or die("you do not have acces to this page!");
$this->warning_types = $this->warning_types + array(
    'suggested-policy-text-changed' => array(
        'type' => 'general',
        'label_ok' => __('No changes in plugin privacy policies have been detected.', 'complianz-gdpr'),
        'label_error' => __('Changes in plugin privacy policies have been detected.', 'complianz-gdpr') . " " . sprintf(__('Please review step %s of the wizard.', 'complianz-gdpr'), $this->steps_to_review_on_changes),
    ),
    'missing-processing-agreements' => array(
        'type' => 'general',
        'label_ok' => __('Processing agreement with all processors and/or Service Providers.', 'complianz-gdpr'),
        'label_error' => sprintf(__('You have processors and/or Service Providers without a processing agreement. %sCreate a processing agreement%s.', 'complianz-gdpr'), '<a href="'.admin_url('admin.php?page=cmplz-wizard&step='.$this->get_step_by_id('company').'&section='.$this->get_section_by_id('sharing_of_data_eu')).'">', '</a>'),
    ),
    'geoip-database-error' => array(
        'type' => 'general',
        'label_error' => sprintf(__("You have enabled Geo IP, but the GEO IP database hasn't been downloaded automatically. If you continue to see this message, download the file from %sMaxMind%s, unzip it, and put it in the %s folder in your WordPress uploads directory", 'complianz-gdpr'),'<a href="https://dev.maxmind.com/geoip/geoip2/geolite2/">',"</a>", "/complianz/maxmind")
    ),
);

//override premium upsell in free
$this->warning_types['no-dnt']['label_error'] = __('The browser setting Do Not Track is not respected', 'complianz-gdpr');

==> wpackagist-plugin-complianz-gdpr-premium-4.6.9.zip: pro/config/warnings.php <==
<?php
defined('ABSPATH') or die("you do not have acces to this page!");
$this->warning_types = $this->warning_types + array(
    'suggested-policy-text-changed' => array(
        'type' => 'general',
        'label_ok' => __('No changes in plugin privacy policies have been detected.', 'complianz-gdpr'),
        'label_error' => __('Changes in plugin privacy policies have been detected.', 'complianz-gdpr') . " " . sprintf(__('Please review step %s of the wizard.', 'complianz-gdpr'), STEP_PLUGINS),
    ),
    'missing-processing-agreements' => array(
        'type' => 'general',
        'label_ok' => __('Processing agreement with all processors and/or Service Providers.', 'complianz-gdpr'),
        'label_error' => sprintf(__('You have processors and/or Service Providers without a processing agreement. %sCreate a processing agreement%s.', 'complianz-gdpr'), '<a href="'.admin_url('admin.php?page=cmplz-wizard&step='.$this->get_step_by_id('company').'&section='.$this->get_section_by_id('sharing_of_data_eu')).'">', '</a>'),
    ),
    'geoip-database-error' => array(
        'type' => 'general',
        'label_error' => sprintf(__("You have enabled Geo IP, but the GEO IP database hasn't been downloaded automatically. If you continue to see this message, download the file from %sMaxMind%s, unzip it, and put it in the %s folder in your WordPress uploads directory", 'complianz-gdpr'),'<a href="https://dev.maxmind.com/geoip/geoip2/geolite2/">',"</a>", "/complianz/maxmind")
    ),
);

//override premium upsell in free
$this->warning_types['no-dnt']['label_error'] = __('The browser setting Do Not Track is not respected', 'complianz-gdpr');
